@@ -299,8 +299,11 @@ void m__system(char **argv, int flags, const char *res_name, pid_t *kid, int *fd
 		}
 		close(pipe_fds[1]);
 
-		if (flags & SUPRESS_STDERR)
-			freopen("/dev/null", "w", stderr);
+		if (flags & SUPRESS_STDERR) {
+			FILE *f = freopen("/dev/null", "w", stderr);
+			if (!f)
+				fprintf(stderr, "freopen(/dev/null) failed\n");
+		}
 		if (argv[0])
 			execvp(argv[0], argv);
 		fprintf(stderr, "Can not exec\n");
